package WWW::Atwiki::Page;

# $Id: Page.pm 2 2009-01-03 10:02:45Z shima $

use warnings;
use strict;
use utf8;

use Encode;
use Jcode;

=head1 NAME

WWW::Atwiki::Page - @wiki のページを表すクラスです。

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';


=head1 SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

    use WWW::Atwiki::Page;

    my $foo = WWW::Atwiki::Page->new();
    ...

=head1 FUNCTIONS

=head2 new

=cut

sub new {
	my $class = shift;
	my %arg   = @_;

	my $self = bless \%arg, $class;

	# UTF-8フラグを付ける
	while ( my( $k, $v ) = each %$self ) {
		$self->{ $k } = $self->_to_utf8( $v );
	}

	return $self;
}

=head2 dump

=cut

sub dump {
	my $self = shift;

	my $out;
	$out  = "ページ番号:"     . $self->number()    . "\n";
	$out .= "ページ名:"       . $self->name()      . "\n";
	$out .= "タグ:"           . $self->tag()       . "\n";
	$out .= "編集モード番号:" . $self->edit_mode() . "\n";
	$out .= '-' x 31 . "\n";
	$out .= $self->content();

	return $out
}

=head2 number

=cut

sub number {
	my $self = shift;
	my $arg  = shift;
	
	$self->{number} = $arg if defined $arg;

	return $self->{number};
}

=head2 name

=cut

sub name {
	my $self = shift;
	my $arg  = shift;
	
	$self->{name} = $self->_to_utf8($arg) if defined $arg;

	return $self->{name};
}

=head2 tag

=cut

sub tag {
	my $self = shift;
	my $arg  = shift;
	
	$self->{tag} = $arg if defined $arg;

	return $self->{tag};
}

=head2 edit_mode

=cut

sub edit_mode {
	my $self = shift;
	my $arg  = shift;
	
	$self->{edit_mode} = $arg if defined $arg;

	return $self->{edit_mode};
}

=head2 content

=cut

sub content {
	my $self = shift;
	my $arg  = shift;
	
	$self->{content} = $self->_to_utf8($arg) if defined $arg;

	return $self->{content};
}

sub _to_utf8 {
	my $self = shift;
	my $str  = shift;

	$str =~ s/\r\n/\n/g;
	$str =~ s/\r/\n/g;
	if ( ! Encode::is_utf8( $str ) ) {
		$str = decode( 'utf8', Jcode->new($str)->utf8 );	
	}

	return $str;
}

=head1 AUTHOR

K.CIMA, C<< <k-cima at shakemid.com> >>

=head1 BUGS

Please report any bugs or feature requests.


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc WWW::Atwiki::Page


=head1 ACKNOWLEDGEMENTS


=head1 COPYRIGHT & LICENSE

Copyright 2009 K.CIMA, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut

1; # End of WWW::Atwiki::Page
