#!perl -T

# ページ編集のテスト

use strict;
use warnings;
use utf8;

use Test::More tests => 11;

use WWW::Atwiki;
use Encode;

my $url = $ENV{ATWIKI_URL};
my $username = $ENV{ATWIKI_USERNAME};
my $password = $ENV{ATWIKI_PASSWORD};
my $testpage = decode( 'utf8', $ENV{ATWIKI_TESTPAGE} );

if ( ! $url || ! $username || ! $password || ! $testpage ) {
	die 'Env ATWIKI_URL, ATWIKI_USERNAME, ATWIKI_PASSWORD, ATWIKI_TESTPAGE are required!'
}

my $wiki = WWW::Atwiki->new(
	url      => $url,
	username => $username,
	password => $password,
);

my $number    = 0;
my $content   = 'てすとだよー';
my $tag       = 'タグ3,タグ4';
my $edit_mode = 0;

my $newpage = WWW::Atwiki::Page->new(
	number    => $number,
	name      => $testpage,
	content   => $content,
	tag       => $tag,
	edit_mode => $edit_mode,
);

$wiki->login();

my $r = $wiki->edit_page( $newpage, notimestamp => 1 );
ok( $r == 1, 'edit page 1' ); 

my $num = $wiki->get_page_number( $testpage );
ok( $num =~ /[1-9]/, 'get page number' );

my $page = $wiki->get_page( $num );
is( $page->name(),      $testpage,  'page name 1' );
is( $page->content(),   $content,   'page content 1' );
is( $page->tag(),       $tag,       'page tag 1' );
is( $page->edit_mode(), $edit_mode, 'page edit_mode 1' );

$number    = $page->number();
$content   = 'てすとですよ';
$tag       = 'タグ1,タグ2';
$edit_mode = 0;

$newpage = WWW::Atwiki::Page->new(
	number    => $number,
	name      => $testpage,
	content   => $content,
	tag       => $tag,
	edit_mode => $edit_mode,
);

$r = $wiki->edit_page( $newpage, notimestamp => 1 );
ok( $r == 1, 'edit page 2' ); 

$page = $wiki->get_page( $num );
is( $page->name(),      $testpage,  'page name 2' );
is( $page->content(),   $content,   'page content 2' );
is( $page->tag(),       $tag,       'page tag 2' );
is( $page->edit_mode(), $edit_mode, 'page edit_mode 2' );

diag( "Testing WWW::Atwiki $WWW::Atwiki::VERSION, Perl $], $^X" );
